@@ -31,7 +31,7 @@ except ImportError:
 from adafruit_platformdetect.constants import boards, chips
 
 
-__version__ = "0.0.0-auto.0"
+__version__ = "3.62.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_PlatformDetect.git"
 
 
@@ -42,7 +42,7 @@ class Board:
         self.detector = detector
         self._board_id = None
 
-    # pylint: disable=invalid-name, protected-access, too-many-return-statements
+    # pylint: disable=invalid-name, protected-access, too-many-return-statements, too-many-lines
     @property
     def id(self) -> Optional[str]:
         """Return a unique id for the detected board, if any."""
@@ -65,6 +65,8 @@ class Board:
             board_id = self._armbian_id() or self._allwinner_variants_id()
         elif chip_id == chips.BCM2XXX:
             board_id = self._pi_id()
+        elif chip_id == chips.AM625X:
+            board_id = self._beaglebone_id()
         elif chip_id == chips.AM33XX:
             board_id = self._beaglebone_id()
         elif chip_id == chips.AM65XX:
@@ -81,6 +83,8 @@ class Board:
             board_id = self._sama5_id()
         elif chip_id == chips.IMX8MX:
             board_id = self._imx8mx_id()
+        elif chip_id == chips.IMX8MP:
+            board_id = self._imx8mp_id()
         elif chip_id == chips.IMX6ULL:
             board_id = self._imx6ull_id()
         elif chip_id == chips.S905Y2:
@@ -95,8 +99,6 @@ class Board:
             board_id = boards.RASPBERRY_PI_PICO
         elif chip_id == chips.S805:
             board_id = boards.ODROID_C1
-        elif chip_id == chips.RK3568B2:
-            board_id = boards.ODROID_M1
         elif chip_id == chips.S905:
             board_id = boards.ODROID_C2
         elif chip_id == chips.S905X3:
@@ -119,7 +121,7 @@ class Board:
             board_id = self._sifive_id()
         elif chip_id == chips.C906:
             board_id = self._allwinner_id()
-        elif chip_id == chips.JH71x0:
+        elif chip_id == chips.JH71X0:
             board_id = self._beaglebone_id()
         elif chip_id == chips.MCP2221:
             board_id = boards.MICROCHIP_MCP2221
@@ -136,13 +138,19 @@ class Board:
         elif chip_id == chips.A10:
             board_id = self._armbian_id()
         elif chip_id == chips.A20:
-            board_id = self._armbian_id()
+            board_id = self._armbian_id() or self._allwinner_variants_id()
         elif chip_id == chips.A64:
             board_id = self._pine64_id()
         elif chip_id == chips.H6:
-            board_id = self._pine64_id() or self._armbian_id()
+            board_id = (
+                self._pine64_id() or self._armbian_id() or self._repka_variants_id()
+            )
         elif chip_id == chips.H5:
-            board_id = self._armbian_id() or self._allwinner_variants_id()
+            board_id = (
+                self._armbian_id()
+                or self._allwinner_variants_id()
+                or self._repka_variants_id()
+            )
         elif chip_id == chips.H616:
             board_id = self._armbian_id() or self._allwinner_variants_id()
         elif chip_id == chips.A33:
@@ -150,7 +158,14 @@ class Board:
         elif chip_id == chips.RK3308:
             board_id = self._rock_pi_id()
         elif chip_id == chips.RK3399:
-            board_id = self._rock_pi_id() or self._armbian_id()
+            board_id = (
+                self._rock_pi_id()
+                or self._armbian_id()
+                or self._diet_pi_id()
+                or self._asus_tinker_board_id()
+            )
+        elif chip_id == chips.RK3399PRO:
+            board_id = self._asus_tinker_board_id()
         elif chip_id == chips.RK3399_T:
             board_id = self._rock_pi_id() or self._armbian_id()
         elif chip_id == chips.ATOM_X5_Z8350:
@@ -160,17 +175,24 @@ class Board:
         elif chip_id == chips.RK3288:
             board_id = self._asus_tinker_board_id()
         elif chip_id == chips.RK3328:
-            board_id = self._rock_pi_id()
+            board_id = self._rock_pi_id() or self._libre_id()
         elif chip_id == chips.RK3566:
             board_id = self._rk3566_id()
         elif chip_id == chips.RK3568:
             board_id = self._rk3568_id()
         elif chip_id == chips.RK3588:
-            board_id = self._rock_pi_id() or self._armbian_id()
+            board_id = (
+                self._rock_pi_id()
+                or self._orange_pi_id()
+                or self._armbian_id()
+                or self._rk3588_id()
+            )
         elif chip_id == chips.RYZEN_V1605B:
             board_id = self._udoo_id()
         elif chip_id == chips.PENTIUM_N3710:
             board_id = self._udoo_id()
+        elif chip_id == chips.CELERON_N5105:
+            board_id = self._intel_n_series_id()
         elif chip_id == chips.STM32MP157:
             board_id = self._stm32mp1_id()
         elif chip_id == chips.STM32MP157DAA1:
@@ -182,11 +204,15 @@ class Board:
         elif chip_id == chips.GENERIC_X86:
             board_id = boards.GENERIC_LINUX_PC
         elif chip_id == chips.TDA4VM:
-            board_id = self._tisk_id()
+            board_id = self._beaglebone_id() or self._tisk_id()
         elif chip_id == chips.D1_RISCV:
             board_id = self._armbian_id()
         elif chip_id == chips.S905X:
             board_id = boards.AML_S905X_CC
+        elif chip_id == chips.CV1800B:
+            board_id = boards.MILKV_DUO
+        elif chip_id == chips.TH1520:
+            board_id = boards.LICHEEPI_4A
         self._board_id = board_id
         return board_id
 
@@ -197,10 +223,16 @@ class Board:
         # Check for Pi boards:
         pi_rev_code = self._pi_rev_code()
         if pi_rev_code:
-            for model, codes in boards._PI_REV_CODES.items():
-                if pi_rev_code in codes:
-                    return model
+            from adafruit_platformdetect.revcodes import PiDecoder
 
+            try:
+                decoder = PiDecoder(pi_rev_code)
+                model = boards._PI_MODELS[decoder.type_raw]
+                if isinstance(model, dict):
+                    model = model[decoder.revision]
+                return model
+            except ValueError:
+                pass
         # We may be on a non-Raspbian OS, so try to lazily determine
         # the version based on `get_device_model`
         else:
@@ -216,8 +248,11 @@ class Board:
 
                 if re_model:
                     pi_model = "".join(re_model.groups())
-                    available_models = boards._PI_REV_CODES.keys()
+                    available_models = boards._PI_MODELS.values()
                     for model in available_models:
+                        # Account for the PI_B_REV1/2 case
+                        if isinstance(model, dict) and pi_model in model:
+                            return model[pi_model]
                         if model == pi_model:
                             return model
 
@@ -268,7 +303,12 @@ class Board:
                 with open("/sys/bus/nvmem/devices/0-00501/nvmem", "rb") as eeprom:
                     eeprom_bytes = eeprom.read(16)
             except FileNotFoundError:
-                return None
+                try:
+                    # Special Case for AI64
+                    with open("/sys/bus/nvmem/devices/2-00500/nvmem", "rb") as eeprom:
+                        eeprom_bytes = eeprom.read(16)
+                except FileNotFoundError:
+                    return None
 
         if eeprom_bytes[:4] != b"\xaaU3\xee":
             return None
@@ -278,6 +318,14 @@ class Board:
         if eeprom_bytes == b"\xaaU3\xeeA335BNLT\x1a\x00\x00\x00":
             return boards.BEAGLEBONE_GREEN
 
+        # BeaglePlay Special Condition
+        # new Beagle EEPROM IDs are 24 Bit, so we need to verify full range
+        if eeprom_bytes == b"\xaaU3\xee\x017\x00\x10.\x00BEAGLE":
+            with open("/sys/bus/nvmem/devices/0-00500/nvmem", "rb") as eeprom:
+                eeprom_bytes = eeprom.read(24)
+            if eeprom_bytes == b"\xaaU3\xee\x017\x00\x10.\x00BEAGLEPLAY-A0-":
+                return boards.BEAGLE_PLAY
+
         id_string = eeprom_bytes[4:].decode("ascii")
         for model, bb_ids in boards._BEAGLEBONE_BOARD_IDS.items():
             for bb_id in bb_ids:
@@ -310,7 +358,7 @@ class Board:
 
     # pylint: disable=too-many-return-statements
     def _armbian_id(self) -> Optional[str]:
-        """Check whether the current board is an OrangePi board."""
+        """Get the current board via the ARMBIAN release field."""
         board_value = self.detector.get_armbian_release_field("BOARD")
         board = None
 
@@ -336,18 +384,24 @@ class Board:
             board = boards.ORANGE_PI_2
         elif board_value == "orangepi3":
             board = boards.ORANGE_PI_3
+        elif board_value == "orangepi3b":
+            board = boards.ORANGE_PI_3B
         elif board_value == "orangepi3-lts":
             board = boards.ORANGE_PI_3_LTS
         elif board_value == "orangepi4":
             board = boards.ORANGE_PI_4
         elif board_value == "orangepi4-lts":
             board = boards.ORANGE_PI_4_LTS
+        elif board_value == "orangepi5-plus":
+            board = boards.ORANGE_PI_5_PLUS
         elif board_value == "orangepi5":
             board = boards.ORANGE_PI_5
         elif board_value == "bananapim2zero":
             board = boards.BANANA_PI_M2_ZERO
         elif board_value == "bananapim2plus":
             board = boards.BANANA_PI_M2_PLUS
+        elif board_value == "bananapim2berry":
+            board = boards.BANANA_PI_M2_BERRY
         elif board_value == "bananapim5":
             board = boards.BANANA_PI_M5
         elif board_value == "orangepizeroplus2-h5":
@@ -362,18 +416,41 @@ class Board:
             board = boards.NANOPI_DUO2
         elif board_value == "nanopineo":
             board = boards.NANOPI_NEO
+        elif board_value == "nanopineo2":
+            board = boards.NANOPI_NEO_2
         elif board_value == "nezha":
             board = boards.LICHEE_RV
         elif board_value == "pcduino2":
             board = boards.PCDUINO2
         elif board_value == "pcduino3":
             board = boards.PCDUINO3
-
+        elif board_value == "rock-3a":
+            board = boards.ROCK_PI_3A
+        elif board_value == "repka-pi3-h5":
+            board = boards.REPKA_PI_3_H5
+        elif board_value == "repka-pi4-h6":
+            board = boards.REPKA_PI_4_H6
+        elif board_value == "milkv_duo":
+            board = boards.MILKV_DUO
         return board
 
     # pylint: enable=too-many-return-statements
 
-    # pylint: enable=too-many-return-statements
+    def _diet_pi_id(self) -> Optional[str]:
+        board_value = self.detector.get_device_model()
+        if "OrangePi 4" in board_value:
+            return boards.ORANGE_PI_4
+        return None
+
+    def _orange_pi_id(self) -> Optional[str]:
+        board_value = self.detector.get_device_model()
+        if "Orange Pi 5 Plus" in board_value:
+            return boards.ORANGE_PI_5_PLUS
+        if "Orange Pi 5" in board_value:
+            return boards.ORANGE_PI_5
+        if "Orange Pi 3B" in board_value:
+            return boards.ORANGE_PI_3B
+        return None
 
     def _sama5_id(self) -> Optional[str]:
         """Check what type sama5 board."""
@@ -415,6 +492,13 @@ class Board:
             return boards.CORAL_EDGE_TPU_DEV
         return None
 
+    def _imx8mp_id(self) -> Optional[str]:
+        """Check what type iMX8M board."""
+        board_value = self.detector.get_device_model()
+        if "NXP i.MX8MPlus SOM" in board_value:
+            return boards.NXP_IMX8MPLUS_SOM
+        return None
+
     def _imx6ull_id(self) -> Optional[str]:
         """Check what type iMX6ULL board."""
         board_value = self.detector.get_device_model()
@@ -451,14 +535,14 @@ class Board:
         """Try to detect the id for Pine64 board or device."""
         board_value = self.detector.get_device_model()
         board = None
-        if "pine64" in board_value.lower():
+        if "pinephone" in board_value.lower():
+            board = boards.PINEPHONE
+        elif "pine64" in board_value.lower():
             board = boards.PINE64
         elif "pine h64" in board_value.lower():
             board = boards.PINEH64
         elif "pinebook" in board_value.lower():
             board = boards.PINEBOOK
-        elif "pinephone" in board_value.lower():
-            board = boards.PINEPHONE
         elif "sopine" in board_value.lower():
             board = boards.SOPINE
         return board
@@ -487,18 +571,38 @@ class Board:
         board = None
         if board_value and "LubanCat-Zero" in board_value:
             board = boards.LUBANCAT_ZERO
-        if board_value and "LubanCat1" in board_value:
+        if board_value and any(x in board_value for x in ("LubanCat1", "LubanCat-1")):
             board = boards.LUBANCAT1
         if board_value and "Radxa CM3 IO" in board_value:
             board = boards.RADXA_CM3
+        if board_value and "Radxa ROCK3 Model C" in board_value:
+            board = boards.ROCK_PI_3C
+        if board_value and "Rockchip RK3566 OPi 3B" in board_value:
+            board = boards.ORANGE_PI_3B
+        if board_value and "Hardkernel ODROID-M1S" in board_value:
+            board = boards.ODROID_M1S
+        elif "quartz64-a" in board_value.lower():
+            board = boards.QUARTZ64_A
         return board
 
     def _rk3568_id(self) -> Optional[str]:
         """Check what type of rk3568 board."""
         board_value = self.detector.get_device_model()
         board = None
-        if board_value and "LubanCat2" in board_value:
+        if board_value and any(x in board_value for x in ("LubanCat2", "LubanCat-2")):
             board = boards.LUBANCAT2
+        if board_value and "ROCK3 Model A" in board_value:
+            board = boards.ROCK_PI_3A
+        if board_value and "Hardkernel ODROID-M1" in board_value:
+            board = boards.ODROID_M1
+        return board
+
+    def _rk3588_id(self) -> Optional[str]:
+        """Check what type of rk3588 board."""
+        board_value = self.detector.get_device_model()
+        board = None
+        if board_value and "LubanCat-4" in board_value:
+            board = boards.LUBANCAT4
         return board
 
     def _rock_pi_id(self) -> Optional[str]:
@@ -517,6 +621,18 @@ class Board:
             board = boards.ROCK_PI_5
         if board_value and "RADXA ROCK 4C+" in board_value.upper():
             board = boards.ROCK_PI_4_C_PLUS
+        if board_value and "RADXA ROCK 4SE" in board_value.upper():
+            board = boards.ROCK_PI_4_SE
+        if board_value and "ROCK3 Model A" in board_value:
+            board = boards.ROCK_PI_3A
+        return board
+
+    def _libre_id(self) -> Optional[str]:
+        """Check what type of Libre Computer board."""
+        board_value = self.detector.get_device_model()
+        board = None
+        if board_value and "Libre Computer ROC-RK3328-CC" in board_value:
+            board = boards.ROC_RK3328_CC
         return board
 
     def _clockwork_pi_id(self) -> Optional[str]:
@@ -539,6 +655,13 @@ class Board:
 
         return None
 
+    def _intel_n_series_id(self) -> Optional[str]:
+        """Try to detect the id of an Intel N-Series board."""
+        if self.detector.check_board_name_value() == "ODROID-H3":
+            return boards.ODROID_H3
+
+        return None
+
     def _j4105_id(self) -> Optional[str]:
         """Try to detect the id of J4105 board."""
         try:
@@ -557,7 +680,12 @@ class Board:
         board_value = self.detector.get_device_model()
         board = None
         if board_value and "ASUS Tinker Board" in board_value:
-            board = boards._ASUS_TINKER_BOARD_IDS
+            board = boards.ASUS_TINKER_BOARD
+        if board_value and "ASUS TINKER BOARD 2" in board_value:
+            board = boards.ASUS_TINKER_BOARD_2
+        if board_value and "ASUS_TINKER_EDGE_R" in board_value:
+            board = boards.ASUS_TINKER_EDGE_R
+
         return board
 
     def _pcduino_board_id(self) -> Optional[str]:
@@ -578,19 +706,47 @@ class Board:
             return board
         board_value = board_value.lower()
         chip_id = self.detector.chip.id
+
+        if "banana pro" in board_value:
+            board = boards.LEMAKER_BANANA_PRO
+
+        if "banana pi m2 berry" in board_value:
+            board = boards.BANANA_PI_M2_BERRY
+
         if "nanopi" in board_value:
             if "neo" in board_value and "SUN8I" in chip_id:
                 board = boards.NANOPI_NEO_AIR
-            # TODO: Add other specifc board contexts here
-        elif "orange pi" in board_value:
+            elif "neo2" in board_value and "H5" in chip_id:
+                board = boards.NANOPI_NEO_2
+        elif any(x in board_value for x in ("orange pi", "orangepi")):
             if "zero" in board_value:
                 if "H5" in chip_id:
                     board = boards.ORANGE_PI_ZERO_PLUS_2H5
                 elif "H616" in chip_id:
                     board = boards.ORANGE_PI_ZERO_2
+        elif "walnutpi-1b" in board_value:
+            board = boards.WALNUT_PI_1B
             # TODO: Add other specifc board contexts here
+
+        elif "lime2" in board_value:
+            board = boards.OLIMEX_LIME2
         return board
 
+    def _repka_variants_id(self) -> Optional[str]:
+        board_value = self.detector.get_device_model()
+        board = None
+        if not board_value:
+            return board
+        board_value = board_value.lower()
+        if "repka-pi3-h5" in board_value:
+            board = boards.REPKA_PI_3_H5
+        if "repka-pi4-h6" in board_value:
+            board = boards.REPKA_PI_4_H6
+
+        return board
+
+    # pylint: disable=too-many-return-statements
+
     def _rp2040_u2if_id(self) -> Optional[str]:
         import hid
 
@@ -617,9 +773,23 @@ class Board:
                 # MacroPad RP2040
                 if product == 0x0107:
                     return boards.MACROPAD_U2IF
+                # Feather RP2040 ThinkInk
+                if product == 0x812C:
+                    return boards.FEATHER_EPD_U2IF
+                # Feather RP2040 RFM
+                if product == 0x812E:
+                    return boards.FEATHER_RFM_U2IF
+                # Feather RP2040 CAN
+                if product == 0x8130:
+                    return boards.FEATHER_CAN_U2IF
+                # KB2040 Kee Board
+                if product == 0x0105:
+                    return boards.KB2040_U2IF
         # Will only reach here if a device was added in chip.py but here.
         raise RuntimeError("RP2040_U2IF device was added to chip but not board.")
 
+    # pylint: enable=too-many-return-statements
+
     def _siemens_simatic_iot2000_id(self) -> Optional[str]:
         """Try to detect if this is a IOT2050 Gateway."""
         board_value = self.detector.get_device_model()
@@ -635,6 +805,11 @@ class Board:
         """Check whether the current board is a SIEMENS SIMATIC IOT2000 Gateway."""
         return self.id in boards._SIEMENS_SIMATIC_IOT2000_IDS
 
+    @property
+    def any_walnutpi(self) -> bool:
+        """Check whether the current board is any defined Walnut Pi."""
+        return self.id in boards._WALNUT_PI_IDS
+
     @property
     def any_nanopi(self) -> bool:
         """Check whether the current board is any defined Nano Pi."""
@@ -695,6 +870,11 @@ class Board:
         """Check whether the current board is any defined 40-pin Odroid."""
         return self.id in boards._ODROID_40_PIN_IDS
 
+    @property
+    def any_odroid_mini_pc(self) -> bool:
+        """Check whether the current board is any defined Odroid Mini PC."""
+        return self.id in boards._ODROID_MINI_PC_IDS
+
     @property
     def khadas_vim3_40_pin(self) -> bool:
         """Check whether the current board is any defined 40-pin Khadas VIM3."""
@@ -720,6 +900,11 @@ class Board:
         """Check whether the current board is any Pine64 device."""
         return self.id in boards._PINE64_DEV_IDS
 
+    @property
+    def any_milkv_board(self) -> bool:
+        """Check whether the current board is any MilkV device."""
+        return self.id in boards._MILKV_IDS_
+
     @property
     def any_rock_pi_board(self) -> bool:
         """Check whether the current board is any Rock Pi device."""
@@ -760,6 +945,11 @@ class Board:
         """Check whether the current board is any BananaPi-family system."""
         return self.id in boards._BANANA_PI_IDS
 
+    @property
+    def any_lemaker(self) -> bool:
+        """Check whether the current board is any LeMaker board."""
+        return self.id in boards._LEMAKER_IDS
+
     @property
     def any_maaxboard(self) -> bool:
         """Check whether the current board is any BananaPi-family system."""
@@ -780,6 +970,21 @@ class Board:
         """Check whether the current board is any defined Libre Computer board."""
         return self.id in boards._LIBRE_COMPUTER_IDS
 
+    @property
+    def any_nxp_navq_board(self) -> bool:
+        """Check whether the current board is any NXP NavQ board"""
+        return self.id in boards._NXP_SOM_IDS
+
+    @property
+    def any_olimex_lime2_board(self):
+        """Check whether the current board is any Pine64 device."""
+        return self.id in boards.OLIMEX_LIME2
+
+    @property
+    def any_repka_board(self):
+        """Check whether the current board is any Repka device."""
+        return self.id in boards._REPKA_PI_IDS
+
     @property
     def os_environ_board(self) -> bool:
         """Check whether the current board is an OS environment variable special case."""
@@ -792,10 +997,14 @@ class Board:
             yield self.board.GREATFET_ONE
             yield self.board.PICO_U2IF
             yield self.board.FEATHER_U2IF
+            yield self.board.FEATHER_CAN_U2IF
+            yield self.board.FEATHER_EPD_U2IF
+            yield self.board.FEATHER_RFM_U2IF
             yield self.board.ITSYBITY_U2IF
             yield self.board.MACROPAD_U2IF
             yield self.board.QTPY_U2IF
             yield self.board.QT2040_TRINKEY_U2IF
+            yield self.board.KB2040_U2IF
 
         return any(condition for condition in lazily_generate_conditions())
 
@@ -813,6 +1022,7 @@ class Board:
             yield self.any_jetson_board
             yield self.any_coral_board
             yield self.any_odroid_40_pin
+            yield self.any_odroid_mini_pc
             yield self.khadas_vim3_40_pin
             yield self.any_96boards
             yield self.any_sifive_board
@@ -827,6 +1037,7 @@ class Board:
             yield self.any_stm32mp1
             yield self.any_lubancat
             yield self.any_bananapi
+            yield self.any_lemaker
             yield self.any_maaxboard
             yield self.any_tisk_board
             yield self.any_siemens_simatic_iot2000
@@ -834,6 +1045,11 @@ class Board:
             yield self.any_pcduino_board
             yield self.any_libre_computer_board
             yield self.generic_linux
+            yield self.any_nxp_navq_board
+            yield self.any_walnutpi
+            yield self.any_olimex_lime2_board
+            yield self.any_repka_board
+            yield self.any_milkv_board
 
         return any(condition for condition in lazily_generate_conditions())
 
@@ -867,6 +1083,21 @@ class Board:
         """Check whether the current board is a Feather RP2040 w/ u2if."""
         return self.id == boards.FEATHER_U2IF
 
+    @property
+    def feather_can_u2if(self) -> bool:
+        """Check whether the current board is a Feather CAN Bus RP2040 w/ u2if."""
+        return self.id == boards.FEATHER_CAN_U2IF
+
+    @property
+    def feather_epd_u2if(self) -> bool:
+        """Check whether the current board is a Feather ThinkInk RP2040 w/ u2if."""
+        return self.id == boards.FEATHER_EPD_U2IF
+
+    @property
+    def feather_rfm_u2if(self) -> bool:
+        """Check whether the current board is a Feather RFM RP2040 w/ u2if."""
+        return self.id == boards.FEATHER_RFM_U2IF
+
     @property
     def itsybitsy_u2if(self) -> bool:
         """Check whether the current board is a Itsy Bitsy w/ u2if."""
@@ -887,6 +1118,11 @@ class Board:
         """Check whether the current board is a QT Py w/ u2if."""
         return self.id == boards.QT2040_TRINKEY_U2IF
 
+    @property
+    def kb2040_u2if(self) -> bool:
+        """Check whether the current board is a KB2040 w/ u2if."""
+        return self.id == boards.KB2040_U2IF
+
     @property
     def binho_nova(self) -> bool:
         """Check whether the current board is an BINHO NOVA."""
