@@ -31,7 +31,7 @@ except ImportError:
 from adafruit_platformdetect.constants import chips
 
 
-__version__ = "0.0.0-auto.0"
+__version__ = "3.62.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_PlatformDetect.git"
 
 
@@ -42,12 +42,11 @@ class Chip:
         self.detector = detector
         self._chip_id = None
 
+    # pylint: disable=invalid-name,too-many-branches,too-many-return-statements
     @property
     def id(
         self,
-    ) -> Optional[
-        str
-    ]:  # pylint: disable=invalid-name,too-many-branches,too-many-return-statements
+    ) -> Optional[str]:
         """Return a unique id for the detected chip, if any."""
         # There are some times we want to trick the platform detection
         # say if a raspberry pi doesn't have the right ID, or for testing
@@ -118,8 +117,22 @@ class Chip:
                         # QT Py RP2040
                         # QT2040 Trinkey
                         # MacroPad RP2040
+                        # Feather RP2040 ThinkInk
+                        # Feather RP2040 RFM
+                        # Feather RP2040 CAN Bus
                         vendor == 0x239A
-                        and product in (0x00F1, 0x00FD, 0x00F7, 0x0109, 0x0107)
+                        and product
+                        in (
+                            0x00F1,
+                            0x00FD,
+                            0x00F7,
+                            0x0109,
+                            0x0107,
+                            0x812C,
+                            0x812E,
+                            0x8130,
+                            0x0105,
+                        )
                     ):
                         self._chip_id = chips.RP2040_U2IF
                         return self._chip_id
@@ -166,6 +179,8 @@ class Chip:
         # pylint: disable=too-many-branches,too-many-statements
         # pylint: disable=too-many-return-statements
         """Attempt to detect the CPU on a computer running the Linux kernel."""
+        if self.detector.check_dt_compatible_value("ti,am625"):
+            return chips.AM625X
         if self.detector.check_dt_compatible_value("ti,am654"):
             return chips.AM65XX
 
@@ -197,11 +212,11 @@ class Chip:
 
         # Older Builds
         if self.detector.check_dt_compatible_value("sifive"):
-            return chips.JH71x0
+            return chips.JH71X0
 
         # Newer Builds
         if self.detector.check_dt_compatible_value("jh7100"):
-            return chips.JH71x0
+            return chips.JH71X0
 
         if self.detector.check_dt_compatible_value("sun8i-a33"):
             return chips.A33
@@ -212,6 +227,9 @@ class Chip:
         if self.detector.check_dt_compatible_value("radxa,rock-4c-plus"):
             return chips.RK3399_T
 
+        if self.detector.check_dt_compatible_value("rockchip,rk3399pro"):
+            return chips.RK3399PRO
+
         if self.detector.check_dt_compatible_value("rockchip,rk3399"):
             return chips.RK3399
 
@@ -227,9 +245,6 @@ class Chip:
         if self.detector.check_dt_compatible_value("rockchip,rk3568"):
             return chips.RK3568
 
-        if self.detector.check_dt_compatible_value("rockchip,rk3568b2"):
-            return chips.RK3568B2
-
         if self.detector.check_dt_compatible_value("rockchip,rk3588"):
             return chips.RK3588
 
@@ -269,9 +284,15 @@ class Chip:
         if self.detector.check_dt_compatible_value("sun20i-d1"):
             return chips.D1_RISCV
 
+        if self.detector.check_dt_compatible_value("imx8mp"):
+            return chips.IMX8MP
+
         if self.detector.check_dt_compatible_value("libretech,aml-s905x-cc"):
             return chips.S905X
 
+        if self.detector.check_dt_compatible_value("light-lpi4a"):
+            return chips.TH1520
+
         linux_id = None
         hardware = self.detector.get_cpuinfo_field("Hardware")
 
@@ -291,6 +312,8 @@ class Chip:
                 ##                print('model_name =', model_name)
                 if "N3710" in model_name:
                     linux_id = chips.PENTIUM_N3710
+                if "N5105" in model_name:
+                    linux_id = chips.CELERON_N5105
                 elif "X5-Z8350" in model_name:
                     linux_id = chips.ATOM_X5_Z8350
                 elif "J4105" in model_name:
@@ -335,6 +358,8 @@ class Chip:
                 linux_id = chips.H5
             if compatible and "odroid-xu4" in compatible:
                 linux_id = chips.EXYNOS5422
+            if compatible and "cvitek,cv180x" in compatible:
+                linux_id = chips.CV1800B
             cpu_model = self.detector.get_cpuinfo_field("cpu model")
 
             if cpu_model is not None:
@@ -399,6 +424,8 @@ class Chip:
         Detect whether the given attribute is the currently-detected chip.  See
         list of constants at the top of this module for available options.
         """
+        if attr == "id":
+            raise AttributeError()  # Avoid infinite recursion
         if self.id == attr:
             return True
         return False
