@@ -4,6 +4,8 @@
 
 """Definition of boards and/or ids"""
 # Allow for aligned constant definitions:
+BEAGLE_PLAY = "BEAGLE_PLAY"
+BEAGLEBONE_AI64 = "BEAGLEBONE_AI64"
 BEAGLEBONE = "BEAGLEBONE"
 BEAGLEBONE_BLACK = "BEAGLEBONE_BLACK"
 BEAGLEBONE_BLUE = "BEAGLEBONE_BLUE"
@@ -22,7 +24,7 @@ BEAGLEV_STARLIGHT = "BEAGLEV_STARLIGHT"
 BEAGLELOGIC_STANDALONE = "BEAGLELOGIC_STANDALONE"
 OSD3358_DEV_BOARD = "OSD3358_DEV_BOARD"
 OSD3358_SM_RED = "OSD3358_SM_RED"
-
+OLIMEX_LIME2 = "OLIMEX_LIME2"
 FEATHER_HUZZAH = "FEATHER_HUZZAH"
 FEATHER_M0_EXPRESS = "FEATHER_M0_EXPRESS"
 GENERIC_LINUX_PC = "GENERIC_LINUX_PC"
@@ -33,6 +35,11 @@ GIANT_BOARD = "GIANT_BOARD"
 
 # ASUS Tinker Boards
 ASUS_TINKER_BOARD = "ASUS_TINKER_BOARD"
+ASUS_TINKER_BOARD_2 = "ASUS_TINKER_BOARD_2"
+ASUS_TINKER_EDGE_R = "ASUS_TINKER_EDGE_R"
+
+# Walnut Pi boards
+WALNUT_PI_1B = "WALNUT_PI_1B"
 
 # Clockwork Pi boards
 CLOCKWORK_CPI3 = "CLOCKWORK_CPI3"
@@ -50,21 +57,29 @@ ORANGE_PI_ZERO_PLUS_2H5 = "ORANGE_PI_ZERO_PLUS_2H5"
 ORANGE_PI_ZERO_PLUS = "ORANGE_PI_ZERO_PLUS"
 ORANGE_PI_ZERO_2 = "ORANGE_PI_ZERO_2"
 ORANGE_PI_3 = "ORANGE_PI_3"
+ORANGE_PI_3B = "ORANGE_PI_3B"
 ORANGE_PI_3_LTS = "ORANGE_PI_3_LTS"
 ORANGE_PI_4 = "ORANGE_PI_4"
 ORANGE_PI_4_LTS = "ORANGE_PI_4_LTS"
 ORANGE_PI_5 = "ORANGE_PI_5"
+ORANGE_PI_5_PLUS = "ORANGE_PI_5_PLUS"
 
 # Nano Pi boards
 NANOPI_NEO_AIR = "NANOPI_NEO_AIR"
 NANOPI_DUO2 = "NANOPI_DUO2"
 NANOPI_NEO = "NANOPI_NEO"
+NANOPI_NEO_2 = "NANOPI_NEO_2"
+
 
 # Banana Pi boards
 BANANA_PI_M2_ZERO = "BANANA_PI_M2_ZERO"
 BANANA_PI_M2_PLUS = "BANANA_PI_M2_PLUS"
+BANANA_PI_M2_BERRY = "BANANA_PI_M2_BERRY"
 BANANA_PI_M5 = "BANANA_PI_M5"
 
+# LeMaker boards
+LEMAKER_BANANA_PRO = "LEMAKER_BANANA_PRO"
+
 # NVIDIA Jetson boards
 JETSON_TX1 = "JETSON_TX1"
 JETSON_TX2 = "JETSON_TX2"
@@ -74,6 +89,8 @@ JETSON_XAVIER = "JETSON_XAVIER"
 JETSON_AGX_ORIN = "JETSON_ORIN"
 JETSON_NANO = "JETSON_NANO"
 JETSON_NX = "JETSON_NX"
+JETSON_ORIN_NANO = "JETSON_ORIN_NANO"
+JETSON_ORIN_NX = "JETSON_ORIN_NX"
 
 # Texas Instruments SK boards
 TI_J721E_SK = "TI_J721E_SK"
@@ -98,6 +115,7 @@ LUBANCAT_STM32MP157 = "LUBANCAT_STM32MP157"
 LUBANCAT_ZERO = "LUBANCAT_ZERO"
 LUBANCAT1 = "LUBANCAT1"
 LUBANCAT2 = "LUBANCAT2"
+LUBANCAT4 = "LUBANCAT4"
 
 # Various Raspberry Pi models
 RASPBERRY_PI_B_REV1 = "RASPBERRY_PI_B_REV1"
@@ -119,14 +137,18 @@ RASPBERRY_PI_4B = "RASPBERRY_PI_4B"
 RASPBERRY_PI_AVNET_IIOT_GW = "RASPBERY_PI_AVNET_IIOT_GW"
 RASPBERRY_PI_400 = "RASPBERRY_PI_400"
 RASPBERRY_PI_CM4 = "RASPBERRY_PI_CM4"
+RASPBERRY_PI_CM4S = "RASPBERRY_PI_CM4S"
+RASPBERRY_PI_5 = "RASPBERRY_PI_5"
 
 ODROID_C1 = "ODROID_C1"
 ODROID_C1_PLUS = "ODROID_C1_PLUS"
 ODROID_C2 = "ODROID_C2"
 ODROID_C4 = "ODROID_C4"
+ODROID_H3 = "ODROID_H3"
 ODROID_N2 = "ODROID_N2"
 ODROID_XU4 = "ODROID_XU4"
 ODROID_M1 = "ODROID_M1"
+ODROID_M1S = "ODROID_M1S"
 
 FTDI_FT232H = "FTDI_FT232H"
 FTDI_FT2232H = "FTDI_FT2232H"
@@ -136,6 +158,7 @@ SIFIVE_UNLEASHED = "SIFIVE_UNLEASHED"
 
 ALLWINER_D1 = "ALLWINER_D1"
 LICHEE_RV = "LICHEE_RV"
+LICHEEPI_4A = "LICHEEPI_4A"
 
 MICROCHIP_MCP2221 = "MICROCHIP_MCP2221"
 
@@ -147,10 +170,14 @@ PCDUINO3 = "PCDUINO3"
 # https://github.com/execuc/u2if
 PICO_U2IF = "PICO_U2IF"
 FEATHER_U2IF = "FEATHER_U2IF"
+FEATHER_CAN_U2IF = "FEATHER_CAN_U2IF"
+FEATHER_EPD_U2IF = "FEATHER_EPD_U2IF"
+FEATHER_RFM_U2IF = "FEATHER_RFM_U2IF"
 ITSYBITSY_U2IF = "ITSYBITSY_U2IF"
 MACROPAD_U2IF = "MACROPAD_U2IF"
 QTPY_U2IF = "QTPY_U2IF"
 QT2040_TRINKEY_U2IF = "QT2040_TRINKEY_U2IF"
+KB2040_U2IF = "KB2040_U2IF"
 
 BINHO_NOVA = "BINHO_NOVA"
 
@@ -162,13 +189,17 @@ PINEH64 = "PINEH64"
 PINEBOOK = "PINEBOOK"
 PINEPHONE = "PINEPHONE"
 SOPINE = "SOPINE"
+QUARTZ64_A = "QUARTZ64_A"
 
 RADXA_ZERO = "RADXA_ZERO"
 RADXA_CM3 = "RADXA_CM3"
 
+ROCK_PI_3A = "ROCK_PI_3A"
+ROCK_PI_3C = "ROCK_PI_3C"
 ROCK_PI_S = "ROCK_PI_S"
 ROCK_PI_4 = "ROCK_PI_4"
 ROCK_PI_4_C_PLUS = "ROCK_PI_4C+"
+ROCK_PI_4_SE = "ROCK_PI_4_SE"
 ROCK_PI_X = "ROCK_PI_X"
 ROCK_PI_E = "ROCK_PI_E"
 ROCK_PI_5 = "ROCK_PI_5"
@@ -187,13 +218,23 @@ UDOO_X86 = "UDOO_X86"
 MAAXBOARD = "MAAXBOARD"
 MAAXBOARD_MINI = "MAAXBOARD_MINI"
 
+# Shenzhen MilkV Technology boards ids
+MILKV_DUO = "MILKV_DUO"
+
 # Khadas VIM3
 KHADAS_VIM3 = "KHADAS_VIM3"
 
 _KHADAS_40_PIN_IDS = (KHADAS_VIM3,)
 
 # Asus Tinkerboard
-_ASUS_TINKER_BOARD_IDS = (ASUS_TINKER_BOARD,)
+_ASUS_TINKER_BOARD_IDS = (
+    ASUS_TINKER_BOARD,
+    ASUS_TINKER_BOARD_2,
+    ASUS_TINKER_EDGE_R,
+)
+
+# WalnutPi
+_WALNUT_PI_IDS = (WALNUT_PI_1B,)
 
 # STM32MP1
 _STM32MP1_IDS = (
@@ -218,17 +259,32 @@ _ORANGE_PI_IDS = (
     ORANGE_PI_ZERO_PLUS,
     ORANGE_PI_ZERO_2,
     ORANGE_PI_3,
+    ORANGE_PI_3B,
     ORANGE_PI_3_LTS,
     ORANGE_PI_4,
     ORANGE_PI_4_LTS,
     ORANGE_PI_5,
+    ORANGE_PI_5_PLUS,
 )
 
 # NanoPi
-_NANOPI_IDS = (NANOPI_NEO_AIR, NANOPI_DUO2, NANOPI_NEO)
+_NANOPI_IDS = (
+    NANOPI_NEO_AIR,
+    NANOPI_DUO2,
+    NANOPI_NEO,
+    NANOPI_NEO_2,
+)
 
 # BananaPI
-_BANANA_PI_IDS = (BANANA_PI_M2_ZERO, BANANA_PI_M2_PLUS, BANANA_PI_M5)
+_BANANA_PI_IDS = (
+    BANANA_PI_M2_ZERO,
+    BANANA_PI_M2_PLUS,
+    BANANA_PI_M2_BERRY,
+    BANANA_PI_M5,
+)
+
+# LeMaker
+_LEMAKER_IDS = (LEMAKER_BANANA_PRO,)
 
 # LubanCat
 _LUBANCAT_IDS = (
@@ -237,6 +293,7 @@ _LUBANCAT_IDS = (
     LUBANCAT_ZERO,
     LUBANCAT1,
     LUBANCAT2,
+    LUBANCAT4,
 )
 
 # Coral boards
@@ -287,6 +344,29 @@ _JETSON_IDS = (
         (
             "nvidia,p3737-0000+p3701-0000",
             "nvidia,p3737-0000+p3701-0004",
+            "nvidia,p3737-0000+p3701-0008",
+            "nvidia,p3737-0000+p3701-0005",
+            "nvidia,p3737-0000+p3701-0001",
+        ),
+    ),
+    (
+        JETSON_ORIN_NX,
+        (
+            "nvidia,p3509-0000+p3767-0000",
+            "nvidia,p3768-0000+p3767-0000",
+            "nvidia,p3509-0000+p3767-0001",
+            "nvidia,p3768-0000+p3767-0001",
+        ),
+    ),
+    (
+        JETSON_ORIN_NANO,
+        (
+            "nvidia,p3509-0000+p3767-0003",
+            "nvidia,p3768-0000+p3767-0003",
+            "nvidia,p3509-0000+p3767-0004",
+            "nvidia,p3768-0000+p3767-0004",
+            "nvidia,p3509-0000+p3767-0005",
+            "nvidia,p3768-0000+p3767-0005",
         ),
     ),
 )
@@ -306,6 +386,7 @@ _RASPBERRY_PI_40_PIN_IDS = (
     RASPBERRY_PI_4B,
     RASPBERRY_PI_AVNET_IIOT_GW,
     RASPBERRY_PI_400,
+    RASPBERRY_PI_5,
 )
 
 _RASPBERRY_PI_CM_IDS = (
@@ -313,6 +394,7 @@ _RASPBERRY_PI_CM_IDS = (
     RASPBERRY_PI_CM3,
     RASPBERRY_PI_CM3_PLUS,
     RASPBERRY_PI_CM4,
+    RASPBERRY_PI_CM4S,
 )
 
 _ODROID_40_PIN_IDS = (
@@ -323,9 +405,14 @@ _ODROID_40_PIN_IDS = (
     ODROID_N2,
     ODROID_XU4,
     ODROID_M1,
+    ODROID_M1S,
 )
 
+_ODROID_MINI_PC_IDS = (ODROID_H3,)
+
 _BEAGLEBONE_IDS = (
+    BEAGLE_PLAY,
+    BEAGLEBONE_AI64,
     BEAGLEBONE,
     BEAGLEBONE_BLACK,
     BEAGLEBONE_BLUE,
@@ -354,8 +441,11 @@ _SIFIVE_IDS = (SIFIVE_UNLEASHED,)
 #   https://github.com/beagleboard/image-builder
 # Thanks to zmatt on freenode #beagle for pointers.
 _BEAGLEBONE_BOARD_IDS = {
+    BEAGLE_PLAY: (("A0", "7.BEAGLE")),
+    BEAGLEBONE_AI64: (("B0", "7.BBONEA")),
     # Original bone/white:
     BEAGLEBONE: (
+        ("A3", "A335BONE00A3"),
         ("A4", "A335BONE00A4"),
         ("A5", "A335BONE00A5"),
         ("A6", "A335BONE00A6"),
@@ -393,150 +483,37 @@ _BEAGLEBONE_BOARD_IDS = {
     BEAGLELOGIC_STANDALONE: (("A", "A335BLGC000A"),),
 }
 
-# Pi revision codes from:
-#   https://www.raspberrypi.org/documentation/hardware/raspberrypi/revision-codes/README.md
-
-# Each tuple here contains both the base codes, and the versions that indicate
-# the Pi is overvolted / overclocked - for 4-digit codes, this will be prefixed
-# with 1000, and for 6-digit codes it'll be prefixed with 1.  These are placed
-# on separate lines.
-
-_PI_REV_CODES = {
-    RASPBERRY_PI_B_REV1: (
-        # Regular codes:
-        "0002",
-        "0003",
-        # Overvolted/clocked versions:
-        "1000002",
-        "1000003",
-    ),
-    RASPBERRY_PI_B_REV2: (
-        "0004",
-        "0005",
-        "0006",
-        "000d",
-        "000e",
-        "000f",
-        "1000005",
-        "1000006",
-        "100000d",
-        "100000e",
-        "100000f",
-    ),
-    RASPBERRY_PI_B_PLUS: ("0010", "0013", "900032", "1000010", "1000013", "1900032"),
-    RASPBERRY_PI_A: ("0007", "0008", "0009", "1000007", "1000008", "1000009"),
-    RASPBERRY_PI_A_PLUS: ("0012", "0015", "900021", "1000012", "1000015", "1900021"),
-    RASPBERRY_PI_CM1: ("0011", "0014", "10000011", "10000014"),
-    RASPBERRY_PI_ZERO: (
-        "900092",
-        "920092",
-        "900093",
-        "920093",
-        "1900092",
-        "1920092",
-        "1900093",
-        "1920093",  # warranty bit 24
-        "2900092",
-        "2920092",
-        "2900093",
-        "2920093",  # warranty bit 25
-    ),
-    RASPBERRY_PI_ZERO_W: ("9000c1", "19000c1", "29000c1"),  # warranty bits
-    RASPBERRY_PI_2B: (
-        "a01040",
-        "a01041",
-        "a02042",
-        "a21041",
-        "a22042",
-        "1a01040",
-        "1a01041",
-        "1a02042",
-        "1a21041",
-        "1a22042",  # warranty bit 24
-        "2a01040",
-        "2a01041",
-        "2a02042",
-        "2a21041",
-        "2a22042",  # warranty bit 25
-        "3a01040",
-        "3a01041",
-        "3a02042",
-        "3a21041",
-        "3a22042",
-    ),
-    RASPBERRY_PI_3B: (
-        "a02082",
-        "a22082",
-        "a32082",
-        "a52082",
-        "1a02082",
-        "1a22082",
-        "1a32082",
-        "1a52082",  # warranty bit 24
-        "2a02082",
-        "2a22082",
-        "2a32082",
-        "2a52082",  # warranty bit 25
-    ),
-    RASPBERRY_PI_3B_PLUS: ("a020d3", "1a020d3", "2a020d3"),  # warranty bits
-    RASPBERRY_PI_AVNET_IIOT_GW: ("60a220b0",),
-    RASPBERRY_PI_CM3: (
-        "a020a0",
-        "a220a0",
-        "1a020a0",
-        "2a020a0",  # warranty bits
-        "1a220a0",
-        "2a220a0",
-    ),
-    RASPBERRY_PI_3A_PLUS: ("9020e0", "19020e0", "29020e0"),  # warranty bits
-    RASPBERRY_PI_CM3_PLUS: ("a02100", "1a02100", "2a02100"),  # warranty bits
-    RASPBERRY_PI_4B: (
-        "a03111",
-        "b03111",
-        "c03111",
-        "a03112",
-        "b03112",
-        "c03112",
-        "b03114",
-        "c03114",
-        "d03114",
-        "a03115",
-        "b03115",
-        "c03115",
-        "d03115",
-        "1a03111",
-        "2a03111",
-        "1b03111",
-        "2b03111",  # warranty bits
-        "1c03111",
-        "2c03111",
-        "1a03112",
-        "2a03112",
-        "1b03112",
-        "2b03112",
-        "1c03112",
-        "2c03112",
-        "80c03114",
-    ),
-    RASPBERRY_PI_400: ("c03130", "c03131"),
-    RASPBERRY_PI_CM4: (
-        "a03140",
-        "a03141",
-        "b03140",
-        "b03141",
-        "c03140",
-        "c03141",
-        "d03140",
-        "d03141",
-    ),
-    RASPBERRY_PI_ZERO_2_W: ("902120", "2902120"),
+_PI_MODELS = {
+    0x00: RASPBERRY_PI_A,
+    0x01: {
+        1.0: RASPBERRY_PI_B_REV1,
+        2.0: RASPBERRY_PI_B_REV2,
+    },
+    0x02: RASPBERRY_PI_A_PLUS,
+    0x03: RASPBERRY_PI_B_PLUS,
+    0x04: RASPBERRY_PI_2B,
+    0x06: RASPBERRY_PI_CM1,
+    0x08: RASPBERRY_PI_3B,
+    0x09: RASPBERRY_PI_ZERO,
+    0x0A: RASPBERRY_PI_CM3,
+    0x0B: RASPBERRY_PI_AVNET_IIOT_GW,
+    0x0C: RASPBERRY_PI_ZERO_W,
+    0x0D: RASPBERRY_PI_3B_PLUS,
+    0x0E: RASPBERRY_PI_3A_PLUS,
+    0x10: RASPBERRY_PI_CM3_PLUS,
+    0x11: RASPBERRY_PI_4B,
+    0x12: RASPBERRY_PI_ZERO_2_W,
+    0x13: RASPBERRY_PI_400,
+    0x14: RASPBERRY_PI_CM4,
+    0x15: RASPBERRY_PI_CM4S,
+    0x17: RASPBERRY_PI_5,
 }
 
 # Onion omega boards
 _ONION_OMEGA_BOARD_IDS = (ONION_OMEGA, ONION_OMEGA2)
 
 # Pine64 boards and devices
-_PINE64_DEV_IDS = (PINE64, PINEH64, PINEBOOK, PINEPHONE, SOPINE)
+_PINE64_DEV_IDS = (PINE64, PINEH64, PINEBOOK, PINEPHONE, SOPINE, QUARTZ64_A)
 
 # Pcduino baords
 _PCDUINO_DEV_IDS = (PCDUINO2, PCDUINO3)
@@ -545,24 +522,27 @@ _ROCK_PI_IDS = (
     ROCK_PI_S,
     ROCK_PI_4,
     ROCK_PI_4_C_PLUS,
+    ROCK_PI_4_SE,
     ROCK_PI_X,
     ROCK_PI_E,
     RADXA_ZERO,
     ROCK_PI_5,
     RADXA_CM3,
+    ROCK_PI_3A,
+    ROCK_PI_3C,
 )
 
 # UDOO
 _UDOO_BOARD_IDS = {UDOO_BOLT_V8: ("SC40-2000-0000-C0|C",), UDOO_X86: ("dummy",)}
 
 # SeeedStudio boards
-_SEEED_BOARD_IDS = ODYSSEY_X86J41X5
+_SEEED_BOARD_IDS = (ODYSSEY_X86J41X5,)
 
 # MaaXBoard boards
 _MAAXBOARD_IDS = ("MAAXBOARD", "MAAXBOARD_MINI")
 
 # Lichee RISC-V boards
-_LICHEE_RISCV_IDS = (LICHEE_RV,)
+_LICHEE_RISCV_IDS = (LICHEE_RV, LICHEEPI_4A)
 
 # Siemens Simatic IOT2000 Gateways
 SIEMENS_SIMATIC_IOT2050_ADV = "SIEMENS_SIMATIC_IOT2050_ADVANCED"
@@ -576,6 +556,27 @@ _SIEMENS_SIMATIC_IOT2000_IDS = (
 
 # Libre Computer Boards
 AML_S905X_CC = "AML-S905X-CC"
+ROC_RK3328_CC = "ROC-RK3328-CC"
 
 # Libre Computer Boards
-_LIBRE_COMPUTER_IDS = (AML_S905X_CC,)
+_LIBRE_COMPUTER_IDS = (
+    AML_S905X_CC,
+    ROC_RK3328_CC,
+)
+
+# NXP System on Module Computer boards
+NXP_IMX8MPLUS_SOM = "NXP_IMX8MPLUS_SOM"
+
+_NXP_SOM_IDS = (NXP_IMX8MPLUS_SOM,)
+
+# Repka-Pi boards
+REPKA_PI_3_H5 = "REPKA_PI_3_H5"
+REPKA_PI_4_H6 = "REPKA_PI_4_H6"
+
+# Repka-Pi
+_REPKA_PI_IDS = (
+    REPKA_PI_3_H5,
+    REPKA_PI_4_H6,
+)
+
+_MILKV_IDS_ = (MILKV_DUO,)
