@@ -5,11 +5,13 @@
 """Definition of chips."""
 A311D = "A311D"
 AM33XX = "AM33XX"
+AM625X = "AM625X"
 AM65XX = "AM65XX"
 DRA74X = "DRA74X"
 TDA4VM = "TDA4VM"
 IMX6ULL = "IMX6ULL"
 IMX8MX = "IMX8MX"
+IMX8MP = "IMX8MP"
 BCM2XXX = "BCM2XXX"
 ESP8266 = "ESP8266"
 EXYNOS5422 = "EXYNOS5422"
@@ -36,7 +38,7 @@ FT232H = "FT232H"
 FT2232H = "FT2232H"
 HFU540 = "HFU540"
 C906 = "C906"
-JH71x0 = "JH71x0"
+JH71X0 = "JH71X0"
 MCP2221 = "MCP2221"
 BINHO = "BINHO"
 MIPS24KC = "MIPS24KC"
@@ -53,14 +55,15 @@ H616 = "H616"
 RK3308 = "RK3308"
 RK3399 = "RK3399"
 RK3399_T = "RK3399_T"
+RK3399PRO = "RK3399PRO"
 RK3328 = "RK3328"
 LPC4330 = "LPC4330"
 RK3288 = "RK3288"
 RK3566 = "RK3566"
 RK3568 = "RK3568"
-RK3568B2 = "RK3568B2"
 RK3588 = "RK3588"
 PENTIUM_N3710 = "PENTIUM_N3710"  # SOC Braswell core
+CELERON_N5105 = "CELERON_N5105"
 STM32F405 = "STM32F405"
 RP2040 = "RP2040"
 STM32MP157 = "STM32MP157"
@@ -70,5 +73,8 @@ ATOM_X5_Z8350 = "X5-Z8350"
 RP2040_U2IF = "RP2040_U2IF"
 D1_RISCV = "D1_RISCV"
 ATOM_J4105 = "ATOM_J4105"
+TH1520 = "TH1520"
 
-BCM_RANGE = {"BCM2708", "BCM2709", "BCM2711", "BCM2835", "BCM2837"}
+BCM_RANGE = {"BCM2708", "BCM2709", "BCM2711", "BCM2712", "BCM2835", "BCM2837"}
+
+CV1800B = "CV1800B"
