@@ -68,6 +68,7 @@ print("Is this a Seeed Board?", detector.board.any_seeed_board)
 print("Is this a UDOO board?", detector.board.any_udoo_board)
 print("Is this an ASUS Tinker board?", detector.board.any_asus_tinker_board)
 print("Is this an STM32MP1 board?", detector.board.any_stm32mp1)
+print("Is this a MilkV board?", detector.board.any_milkv_board)
 print("Is this a generic Linux PC?", detector.board.generic_linux)
 print(
     "Is this an OS environment variable special case?", detector.board.os_environ_board
@@ -85,6 +86,9 @@ if detector.board.any_pynq_board:
 if detector.board.any_orange_pi:
     print("Orange Pi detected.")
 
+if detector.board.any_lemaker:
+    print("LeMaker board detected.")
+
 if detector.board.any_odroid_40_pin:
     print("Odroid detected.")
 
@@ -111,3 +115,9 @@ if detector.board.any_lubancat:
 
 if detector.board.any_siemens_simatic_iot2000:
     print("Siemens Simatic IOT2000 Gateway detected.")
+
+if detector.board.any_nxp_navq_board:
+    print("NXP NavQ board detected.")
+
+if detector.board.any_walnutpi:
+    print("Walnut Pi detected.")
